# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 0.0.x   | :white_check_mark: |

## Reporting a Vulnerability

Report vulnerabilities either by raising an [issue](https://github.com/latiotech/LAST/issues), or emailing info@latio.tech. 

Please be kind and don't report whatever SCA scanner you pointed at this thing; instead if you're concerned, encourage your developers to bump the version and submit a pull request. 

If you've discovered a legitimate vulnerability that you can personally reproduce or discuss as a possible exploit, we're happy to hear about it.
